/**************
 
 This is a Processing parser for .SRT files, a widely used subtitle text file format.
 .SRT file information is obtained from: http://en.wikipedia.org/wiki/SubRip
 
 The SubRip file format is "perhaps the most basic of all subtitle formats."
 SubRip files are named with the extension .srt,
 and contain formatted UTF-8 plain text.
 The time format used is hours:minutes:seconds,milliseconds.
 The decimal separator used is the comma,
 since the program was written in France;
 the line break used is the CR+LF pair.
 Subtitles are numbered sequentially, starting at 1.
 The format for an .SRT subtitle is:
 
 Subtitle number
 Start time --> End time
 Text of subtitle (one or more lines)
 Blank line
 
 These are parsed into a series of SubtitleUnit data structures
 and stored in the Java Vector, subtitleVector.
 (See class definition for SubtitleUnit below.)
 
 ***************/
//-----------------------------------------------------------
// Which .SRT file should we load (from the sketch's "data" folder)?
String srtFilename = "THX_1138.srt";

int compteur=0;
String sub_text="";
int adjuster;

//-----------------------------------------------------------
void setup() {
  size(600, 400);
  textAlign(CENTER, CENTER);
  subtitleVector = new ArrayList();
  creervecteur();
  // recuperer le passage du dernier sous-titre
  SubtitleUnit SU=(SubtitleUnit) subtitleVector.get(subtitleVector.size()-1);
  length_srt=SU.endTime+5000;
  
  adjuster=millis(); // commencer le compteur maintenant
}

void draw() {
  background (0);
  fill(255);

  int this_moment=millis()-adjuster;

  if (this_moment > sub_end) {
    compteur++;
    new_subtitle();

    if (compteur > subtitleVector.size()-1) { // retourner au début 
      compteur=0;
    }
  } 
  if (this_moment > sub_start && this_moment < sub_end) {
    text(sub_text, width/2, height*0.4);
  }
  text("compteur "+compteur + " - " + sub_text, width/2, height*40);

  text(this_moment, width/2, height*0.60);
  text(sub_start + " - "+ sub_end, width/2, height*0.66);

  // dessiner la barre de défilement
  noStroke();
  fill(0, 100, 10);
  rect(0, height-20, width, 20);
  stroke(255);
  float p=map(millis()-adjuster, 0, length_srt, 0, width);
  line(p, height-20, p, height);
}

void mouseClicked() {
  if (mouseY > height-20) {
    adjuster=millis()-int(map(mouseX, 0, width, 0, length_srt));
    find_subtitle();
  }
}
